
#ifndef KONTACTINTERFACE_EXPORT_H
#define KONTACTINTERFACE_EXPORT_H

#ifdef KONTACTINTERFACE_STATIC_DEFINE
#  define KONTACTINTERFACE_EXPORT
#  define KONTACTINTERFACE_NO_EXPORT
#else
#  ifndef KONTACTINTERFACE_EXPORT
#    ifdef KPim6KontactInterface_EXPORTS
        /* We are building this library */
#      define KONTACTINTERFACE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KONTACTINTERFACE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KONTACTINTERFACE_NO_EXPORT
#    define KONTACTINTERFACE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KONTACTINTERFACE_DECL_DEPRECATED
#  define KONTACTINTERFACE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KONTACTINTERFACE_DECL_DEPRECATED_EXPORT
#  define KONTACTINTERFACE_DECL_DEPRECATED_EXPORT KONTACTINTERFACE_EXPORT KONTACTINTERFACE_DECL_DEPRECATED
#endif

#ifndef KONTACTINTERFACE_DECL_DEPRECATED_NO_EXPORT
#  define KONTACTINTERFACE_DECL_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT KONTACTINTERFACE_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KONTACTINTERFACE_NO_DEPRECATED
#    define KONTACTINTERFACE_NO_DEPRECATED
#  endif
#endif
#include <kontactinterface_version.h>

#define KONTACTINTERFACE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KONTACTINTERFACE_NO_DEPRECATED)
#  undef KONTACTINTERFACE_DEPRECATED
#  define KONTACTINTERFACE_DEPRECATED_EXPORT KONTACTINTERFACE_EXPORT
#  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT
#elif defined(KONTACTINTERFACE_NO_DEPRECATED_WARNINGS)
#  define KONTACTINTERFACE_DEPRECATED
#  define KONTACTINTERFACE_DEPRECATED_EXPORT KONTACTINTERFACE_EXPORT
#  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT
#else
#  define KONTACTINTERFACE_DEPRECATED KONTACTINTERFACE_DECL_DEPRECATED
#  define KONTACTINTERFACE_DEPRECATED_EXPORT KONTACTINTERFACE_DECL_DEPRECATED_EXPORT
#  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KONTACTINTERFACE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KONTACTINTERFACE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KONTACTINTERFACE_NO_DEPRECATED
#  define KONTACTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT KONTACTINTERFACE_VERSION
#endif
#ifdef KONTACTINTERFACE_NO_DEPRECATED_WARNINGS
#  define KONTACTINTERFACE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KONTACTINTERFACE_DEPRECATED_WARNINGS_SINCE
#  ifdef KONTACTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KONTACTINTERFACE_DEPRECATED_WARNINGS_SINCE KONTACTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KONTACTINTERFACE_DEPRECATED_WARNINGS_SINCE KONTACTINTERFACE_VERSION
#  endif
#endif

#ifndef KONTACTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KONTACTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KONTACTINTERFACE_DEPRECATED
#  define KONTACTINTERFACE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KONTACTINTERFACE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KONTACTINTERFACE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KONTACTINTERFACE_EXPORT_H */
