// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KONTACTINTERFACE_VERSION_H
#define KONTACTINTERFACE_VERSION_H

#define KONTACTINTERFACE_VERSION_STRING "6.7.1"
#define KONTACTINTERFACE_VERSION_MAJOR 6
#define KONTACTINTERFACE_VERSION_MINOR 7
#define KONTACTINTERFACE_VERSION_PATCH 1
#define KONTACTINTERFACE_VERSION ((6<<16)|(7<<8)|(1))

#endif
